
# Type: named thing




URI: [https://example.com/test65/NamedThing](https://example.com/test65/NamedThing)


![img](http://yuml.me/diagram/nofunky;dir:TB/class/[NamedThing&#124;subject:string%20%3F]^-[ChildOfNamedThing])

## Children

 * [ChildOfNamedThing](ChildOfNamedThing.md)

## Referenced by class


## Attributes


### Own

 * [subject](subject.md)  <sub>OPT</sub>
    * range: [String](types/String.md)

### Domain for slot:

 * [subject](subject.md)  <sub>OPT</sub>
    * range: [String](types/String.md)
